==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Effect/filewriter/translations/filewriter_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="31"/>
        <source>File Writer Plugin</source>
        <translation>Wtyczka Zapis pliku</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>About File Writer Plugin</source>
        <translation>O wtyczce Zapis pliku</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="53"/>
        <source>Qmmp File Writer Plugin</source>
        <translation>Wtyczka Zapis pliku dla Qmmp</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation>Ustawienia wtyczki Zapis pliku</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>Katalog wyjściowy:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>Output file name:</source>
        <translation>Nazwa pliku wyjściowego:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Quality:</source>
        <translation>Jakość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.2.orig.tar.bz2: qmmp-1.2.2/src/plugins/Effect/filewriter/translations/filewriter_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="31"/>
        <source>File Writer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>About File Writer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="53"/>
        <source>Qmmp File Writer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>Katalog wyjściowy:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>Output file name:</source>
        <translation>Nazwa pliku wyjściowego:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
</context>
</TS>
